]> granicus.if.org Git - neomutt/commitdiff
replace 'IMAP_MBOX' with 'struct ImapMbox'
authorRichard Russon <rich@flatcap.org>
Tue, 16 May 2017 13:18:30 +0000 (14:18 +0100)
committerRichard Russon <rich@flatcap.org>
Tue, 16 May 2017 14:21:29 +0000 (15:21 +0100)
browser.c
imap/browse.c
imap/command.c
imap/imap.c
imap/imap.h
imap/imap_private.h
imap/message.c
imap/util.c

index 0f01958bfd85f25ebfb4e226c5e78fe2e6761157..2c006c1a30695d5c54a20943b44d8f36a0efa6a1 100644 (file)
--- a/browser.c
+++ b/browser.c
@@ -1518,7 +1518,7 @@ void _mutt_select_file(char *f, size_t flen, int flags, char ***files, int *numf
         else
         {
           char msg[SHORT_STRING];
-          IMAP_MBOX mx;
+          struct ImapMbox mx;
           int nentry = menu->current;
 
           imap_parse_path(state.entry[nentry].name, &mx);
index 3fbe3c13f43035a6cb9029fc91266ff5fb5d514e..90d3cfe45707111ec65d564120d4519a8bda3177 100644 (file)
@@ -36,7 +36,7 @@ static void imap_add_folder(char delim, char *folder, int noselect, int noinferi
 {
   char tmp[LONG_STRING];
   char relpath[LONG_STRING];
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   struct Buffy *b = NULL;
 
   if (imap_parse_path(state->folder, &mx))
@@ -112,7 +112,7 @@ static int browse_add_list_result(struct ImapData *idata, const char *cmd,
                                   struct browser_state *state, short isparent)
 {
   struct ImapList list;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   int rc;
 
   if (imap_parse_path(state->folder, &mx))
@@ -161,7 +161,7 @@ int imap_browse(char *path, struct browser_state *state)
   char ctmp;
   short showparents = 0;
   int save_lsub;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
 
   if (imap_parse_path(path, &mx))
   {
@@ -316,7 +316,7 @@ fail:
 int imap_mailbox_create(const char *folder)
 {
   struct ImapData *idata = NULL;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   char buf[LONG_STRING];
   short n;
 
@@ -370,7 +370,7 @@ fail:
 int imap_mailbox_rename(const char *mailbox)
 {
   struct ImapData *idata = NULL;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   char buf[LONG_STRING];
   char newname[SHORT_STRING];
 
index 3a4e069dfeb6d8f6277f01a8ae48c387b04d76bf..1f2a073710ddf56c2742f0e2eeeb52c28962c632 100644 (file)
@@ -485,7 +485,7 @@ static void cmd_parse_status(struct ImapData *idata, char *s)
   char *mailbox = NULL;
   char *value = NULL;
   struct Buffy *inc = NULL;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   int count;
   IMAP_STATUS *status = NULL;
   unsigned int olduv, oldun;
index 44c341f1a6d025853760080580135bec12d8c5b5..3e7be3d71a2c7ba383f7af3d05088df70f06bdea 100644 (file)
@@ -53,7 +53,7 @@ static void imap_set_flag(struct ImapData *idata, int aclbit, int flag,
 int imap_access(const char *path, int flags)
 {
   struct ImapData *idata = NULL;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   char buf[LONG_STRING];
   char mailbox[LONG_STRING];
   char mbox[LONG_STRING];
@@ -123,7 +123,7 @@ int imap_create_mailbox(struct ImapData *idata, char *mailbox)
   return 0;
 }
 
-int imap_rename_mailbox(struct ImapData *idata, IMAP_MBOX *mx, const char *newname)
+int imap_rename_mailbox(struct ImapData *idata, struct ImapMbox *mx, const char *newname)
 {
   char oldmbox[LONG_STRING];
   char newmbox[LONG_STRING];
@@ -140,7 +140,7 @@ int imap_rename_mailbox(struct ImapData *idata, IMAP_MBOX *mx, const char *newna
   return 0;
 }
 
-int imap_delete_mailbox(struct Context *ctx, IMAP_MBOX *mx)
+int imap_delete_mailbox(struct Context *ctx, struct ImapMbox *mx)
 {
   char buf[LONG_STRING], mbox[LONG_STRING];
   struct ImapData *idata = NULL;
@@ -556,7 +556,7 @@ static int imap_open_mailbox(struct Context *ctx)
   char buf[LONG_STRING];
   char bufout[LONG_STRING];
   int count = 0;
-  IMAP_MBOX mx, pmx;
+  struct ImapMbox mx, pmx;
   int rc;
 
   if (imap_parse_path(ctx->path, &mx))
@@ -770,7 +770,7 @@ static int imap_open_mailbox_append(struct Context *ctx, int flags)
   struct ImapData *idata = NULL;
   char buf[LONG_STRING];
   char mailbox[LONG_STRING];
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   int rc;
 
   if (imap_parse_path(ctx->path, &mx))
@@ -1470,7 +1470,7 @@ static int imap_check_mailbox_reopen(struct Context *ctx, int *index_hint)
 /* split path into (idata,mailbox name) */
 static int imap_get_mailbox(const char *path, struct ImapData **hidata, char *buf, size_t blen)
 {
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
 
   if (imap_parse_path(path, &mx))
   {
@@ -1855,7 +1855,7 @@ int imap_subscribe(char *path, int subscribe)
   char mbox[LONG_STRING];
   char errstr[STRING];
   struct Buffer err, token;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
 
   if (!mx_is_imap(path) || imap_parse_path(path, &mx) || !mx.mbox)
   {
@@ -1981,7 +1981,7 @@ int imap_complete(char *dest, size_t dlen, char *path)
   char completion[LONG_STRING];
   int clen, matchlen = 0;
   int completions = 0;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   int rc;
 
   if (imap_parse_path(path, &mx))
@@ -2071,7 +2071,7 @@ int imap_fast_trash(struct Context *ctx, char *dest)
   char mmbox[LONG_STRING];
   char prompt[LONG_STRING];
   int rc;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   int triedcreate = 0;
 
   idata = ctx->data;
index 590b01e3686b840f7c435f58b80cd45d1a816717..9052ffcc4d7fcf3edbb2f6f74484d95dd03ba8d8 100644 (file)
 #include "mailbox.h"
 
 /* -- data structures -- */
-typedef struct
+struct ImapMbox
 {
   struct Account account;
   char *mbox;
-} IMAP_MBOX;
+};
 
 /* imap.c */
 int imap_access(const char *, int);
 int imap_check_mailbox(struct Context *ctx, int force);
-int imap_delete_mailbox(struct Context *ctx, IMAP_MBOX *mx);
+int imap_delete_mailbox(struct Context *ctx, struct ImapMbox *mx);
 int imap_sync_mailbox(struct Context *ctx, int expunge);
 int imap_close_mailbox(struct Context *ctx);
 int imap_buffy_check(int force, int check_stats);
@@ -62,7 +62,7 @@ void imap_logout_all(void);
 
 /* util.c */
 int imap_expand_path(char *path, size_t len);
-int imap_parse_path(const char *path, IMAP_MBOX *mx);
+int imap_parse_path(const char *path, struct ImapMbox *mx);
 void imap_pretty_mailbox(char *path);
 
 int imap_wait_keepalive(pid_t pid);
index 08ad4e01658414098ea2ba2e03d2dae654935ee0..d2092558c101412ea6fe700ba0b47981f0b9b323 100644 (file)
@@ -231,7 +231,7 @@ struct ImapData
 /* imap.c */
 int imap_check(struct ImapData *idata, int force);
 int imap_create_mailbox(struct ImapData *idata, char *mailbox);
-int imap_rename_mailbox(struct ImapData *idata, IMAP_MBOX *mx, const char *newname);
+int imap_rename_mailbox(struct ImapData *idata, struct ImapMbox *mx, const char *newname);
 IMAP_STATUS *imap_mboxcache_get(struct ImapData *idata, const char *mbox, int create);
 void imap_mboxcache_free(struct ImapData *idata);
 int imap_exec_msgset(struct ImapData *idata, const char *pre, const char *post,
@@ -290,7 +290,7 @@ int imap_mxcmp(const char *mx1, const char *mx2);
 char *imap_next_word(char *s);
 time_t imap_parse_date(char *s);
 void imap_make_date(char *buf, time_t timestamp);
-void imap_qualify_path(char *dest, size_t len, IMAP_MBOX *mx, char *path);
+void imap_qualify_path(char *dest, size_t len, struct ImapMbox *mx, char *path);
 void imap_quote_string(char *dest, size_t slen, const char *src);
 void imap_unquote_string(char *s);
 void imap_munge_mbox_name(struct ImapData *idata, char *dest, size_t dlen, const char *src);
index b9dca6fe81bb59834b127576d716cff45cacf4cd..7d49d8bbb2a7dde329dd3a18623c915db509fc20 100644 (file)
@@ -920,7 +920,7 @@ int imap_append_message(struct Context *ctx, struct Message *msg)
   struct Progress progressbar;
   size_t sent;
   int c, last;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   int rc;
 
   idata = ctx->data;
@@ -1054,7 +1054,7 @@ int imap_copy_messages(struct Context *ctx, struct Header *h, char *dest, int de
   char prompt[LONG_STRING];
   int rc;
   int n;
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   int err_continue = MUTT_NO;
   int triedcreate = 0;
 
index 7368369eaea3bb330fc81482d9df7ca5f2f4344f..c01a2167ccaaed440c530a1ff5b79c4af7549beb 100644 (file)
@@ -47,7 +47,7 @@
  *   fails, which it might if there isn't enough room in the buffer. */
 int imap_expand_path(char *path, size_t len)
 {
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   struct ImapData *idata = NULL;
   struct CissUrl url;
   char fixedpath[LONG_STRING];
@@ -118,7 +118,7 @@ void imap_get_parent(char *output, const char *mbox, size_t olen, char delim)
  */
 void imap_get_parent_path(char *output, const char *path, size_t olen)
 {
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   struct ImapData *idata = NULL;
   char mbox[LONG_STRING] = "";
 
@@ -151,7 +151,7 @@ void imap_get_parent_path(char *output, const char *path, size_t olen)
  */
 void imap_clean_path(char *path, size_t plen)
 {
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   struct ImapData *idata = NULL;
   char mbox[LONG_STRING] = "";
 
@@ -177,7 +177,7 @@ static int imap_hcache_namer(const char *path, char *dest, size_t dlen)
 
 header_cache_t *imap_hcache_open(struct ImapData *idata, const char *path)
 {
-  IMAP_MBOX mx;
+  struct ImapMbox mx;
   struct CissUrl url;
   char cachepath[LONG_STRING];
   char mbox[LONG_STRING];
@@ -258,7 +258,7 @@ int imap_hcache_del(struct ImapData *idata, unsigned int uid)
 /* imap_parse_path: given an IMAP mailbox name, return host, port
  *   and a path IMAP servers will recognize.
  * mx.mbox is malloc'd, caller must free it */
-int imap_parse_path(const char *path, IMAP_MBOX *mx)
+int imap_parse_path(const char *path, struct ImapMbox *mx)
 {
   static unsigned short ImapPort = 0;
   static unsigned short ImapsPort = 0;
@@ -394,7 +394,7 @@ int imap_mxcmp(const char *mx1, const char *mx2)
  *   look nice. */
 void imap_pretty_mailbox(char *path)
 {
-  IMAP_MBOX home, target;
+  struct ImapMbox home, target;
   struct CissUrl url;
   char *delim = NULL;
   int tlen;
@@ -686,9 +686,9 @@ void imap_make_date(char *buf, time_t timestamp)
            tm->tm_min, tm->tm_sec, (int) tz / 60, (int) abs((int) tz) % 60);
 }
 
/* imap_qualify_path: make an absolute IMAP folder target, given IMAP_MBOX
  *   and relative path. */
-void imap_qualify_path(char *dest, size_t len, IMAP_MBOX *mx, char *path)
+void imap_qualify_path(char *dest, size_t len, struct ImapMbox *mx, char *path)
 {
   struct CissUrl url;
@@ -686,9 +686,9 @@ void imap_make_date(char *buf, time_t timestamp)
 }
 
-/* imap_qualify_path: make an absolute IMAP folder target, given IMAP_MBOX
+/* imap_qualify_path: make an absolute IMAP folder target, given ImapMbox
  *   and relative path. */